@@ -1,8 +1,8 @@
 #' @docType package
 #' @name MazamaSpatialUtils
 #' @title Mazama Science spatial data and utility functions.
-#' @description This package contains code to convert various spatial datasets into .RData files
-#' with uniformly named identifiers including:
+#' @description This package contains code to convert various spatial datasets
+#' into .rda files with uniformly named identifiers including:
 #' \itemize{
 #' \item{ countryCode -- ISO 3166-1 alpha-2}
 #' \item{ countryName -- Country name}
@@ -12,22 +12,20 @@
 #' \item{ latitude -- degrees North}
 #' \item{ area -- m^2}
 #' }
-#' The parameters listed above will be found in the @@data slot of each spatial
-#' dataset whose source data has an equivalent field. The only field guaranteed
+#' The only field guaranteed
 #' to exist in every dataset is \code{countryCode}.
 #'
 #' The following additional standards are applied during the data conversion process:
 #' \itemize{
-#' \item{ all spatial data are converted to a purely geographic projection (\code{CRS("+proj=longlat +ellps=GRS80 +datum=NAD83 +no_defs"}) }
+#' \item{ all spatial data are converted to a purely geographic North American projection (\url{https://epsg.io/4269}) }
 #' \item{ no duplicated rows in the dataframe (conversion to \strong{multi-}polygons) }
 #' \item{ lowerCamelCase, human readable names replace original parameter names }
 #' \item{ redundant, software-internal or otherwise unuseful data columns may be dropped }
-#' \item{ parameters may be added to the @@data dataframe }
 #' \item{ latitude and longitude of polygon centroids may be added }
 #' }
 #'
 #' Utility functions allow users to determine the country, state, county and timezones
-#' associated with a set of locations, e.g. environmental monitoring sites.
+#' associated with a set of locations, _e.g._ environmental monitoring sites.
 #'
 #' The uniformity of identifiers in the spatial datasets also makes it easy to generate maps
 #' with data from any dataset that uses standard ISO codes for countries or states.
@@ -40,12 +38,11 @@ spatialEnv <- new.env(parent = emptyenv())
 spatialEnv$dataDir <- NULL
 
 #' @docType data
-#' @keywords environment
 #' @name SpatialDataDir
 #' @title Directory for spatial data
 #' @format Absolute path string.
 #' @description This package maintains an internal directory location which users can set
-#' using \code{setSpatialDataDir()}. All package functions use this directory whenever datasets
+#' using \code{\link{setSpatialDataDir}}. All package functions use this directory whenever datasets
 #' are created or loaded.
 #'
 #' The default setting when the package is loaded is \code{getwd()}.
@@ -53,9 +50,7 @@ spatialEnv$dataDir <- NULL
 #' @seealso setSpatialDataDir
 NULL
 
-#' @keywords environment
 #' @export
-#' @import sp
 #' @title Get package data directory
 #' @description Returns the package data directory where spatial data is located.
 #' @return Absolute path string.
@@ -70,7 +65,6 @@ getSpatialDataDir <- function() {
   }
 }
 
-#' @keywords environment
 #' @export
 #' @title Set package data directory
 #' @param dataDir Directory where spatial datasets are created.
@@ -93,7 +87,6 @@ setSpatialDataDir <- function(dataDir) {
   return(invisible(old))
 }
 
-#' @keywords environment
 #' @keywords internal
 #' @export
 #' @title Remove package data directory
@@ -102,15 +95,15 @@ setSpatialDataDir <- function(dataDir) {
 #' @seealso SpatialDataDir
 #' @seealso getSpatialDataDir
 #' @seealso setSpatialDataDir
-removeSpatialDataDir <- function() {
+.removeSpatialDataDir <- function() {
   old <- spatialEnv$dataDir
   spatialEnv$dataDir <- NULL
+  return(invisible(old))
 }
 
 
 # ----- Code <-> Name conversion functions  ------------------------------------
 
-#' @keywords conversion
 #' @export
 #' @title Convert from ISO2 to ISO3 country codes
 #' @param countryCodes Vector of ISO 3166-1 alpha-2 country codes.
@@ -131,7 +124,6 @@ iso2ToIso3 <- function(countryCodes) {
   }
 }
 
-#' @keywords conversion
 #' @export
 #' @title Convert from ISO3 to ISO2 country codes
 #' @param countryCodes Vector of ISO 3166-1 alpha-3 codes.
@@ -152,7 +144,6 @@ iso3ToIso2 <- function(countryCodes) {
   }
 }
 
-#' @keywords conversion
 #' @export
 #' @title Convert country codes to country names
 #' @param countryCodes Vector of ISO 3166-1 alpha-2 country codes.
@@ -167,7 +158,6 @@ codeToCountry <- function(countryCodes) {
   return(countryNames)
 }
 
-#' @keywords conversion
 #' @export
 #' @title Convert country names to country codes
 #' @param countryNames Vector of English language country names.
@@ -182,7 +172,6 @@ countryToCode <- function(countryNames) {
   return(countryCodes)
 }
 
-#' @keywords conversion
 #' @export
 #' @title Convert state codes to state nnames
 #' @param stateCodes Vector of state codes.
@@ -190,9 +179,8 @@ countryToCode <- function(countryNames) {
 #' @param dataset Name of dataset containing state-level identifiers.
 #' @description Converts a vector of ISO 3166-2 alpha-2 state codes to the
 #' corresponding English names.
-#' @details For this function to work, you must first run
-#' \code{initializeSpatialData()} to
-#' download, convert and install the necessary spatial data.
+#' @details For this function to work, you must install and load the
+#' "NaturalEarthAdm1" dataset.
 #' @return A vector of English state names or NA.
 #' @seealso convertNaturalEarthAdm1
 codeToState <- function(
@@ -207,10 +195,10 @@ codeToState <- function(
          call. = FALSE)
   }
 
-  SPDF <- get(dataset)
+  SFDF <- get(dataset)
 
   # Remove NA state codes
-  stateTable <- SPDF@data[!is.na(SPDF@data$stateCode),]
+  stateTable <- SFDF[!is.na(SFDF$stateCode),]
 
   # Filter by countryCodes to make searching faster
   if (!is.null(countryCodes))
@@ -236,7 +224,6 @@ codeToState <- function(
 
 }
 
-#' @keywords conversion
 #' @export
 #' @title Convert state names to state codes
 #' @param stateNames Vector of state names to be converted.
@@ -244,9 +231,8 @@ codeToState <- function(
 #' @param dataset Name of dataset containing state-level identifiers.
 #' @description Converts a vector of state names to an ISO 3166-2 two character
 #' state codes.
-#' @details For this function to work, you must first run
-#' \code{initializeSpatialData()} to
-#' download, convert and install the necessary spatial data.
+#' @details For this function to work, you must install and load the
+#' "NaturalEarthAdm1" dataset.
 #' @examples
 #' \dontrun{
 #' stateToCode("Washington")
@@ -267,10 +253,10 @@ stateToCode <- function(
          call. = FALSE)
   }
 
-  SPDF <- get(dataset)
+  SFDF <- get(dataset)
 
   # Remove NA state codes
-  stateTable <- SPDF@data[!is.na(SPDF@data$stateCode),]
+  stateTable <- SFDF[!is.na(SFDF$stateCode),]
 
   # Filter by countryCodes to make searching faster
   if ( !is.null(countryCodes) )
@@ -288,67 +274,74 @@ stateToCode <- function(
 # ===== Mapshaper ==============================================================
 
 #' @export
-#' @title Simplify SpatialPolygonsDataFrame
-#' @param SPDF Object of class SpatialPolygonsDataFrame.
+#' @title Simplify simple features data frame
+#' @param SFDF Object of class simple features data frame.
 #' @param keep Proportion of points to retain (0-1; default 0.05)
 #' @param ... Arguments passed to \code{rmapshaper::ms_simplify()}
 #' @description Simplify a spatial polygons dataframe. This is a convenience
-#' wrapper for \code{rmapshaper::ms_simplify()}
+#' wrapper for \code{\link[rmapshaper]{ms_simplify}}
 #' @return A simplified spatial polygons dataframe.
 #' @examples
 #' \dontrun{
-#' FR <- subset(SimpleCountries, countryCode == 'FR')
+#' library(MazamaSpatialUtils)
+#' FR <-
+#'   SimpleCountries %>%
+#'   dplyr::filter(countryCode == "FR")
 #' par(mfrow = c(3, 3), mar = c(1, 1, 3, 1))
 #' for (i in 9:1) {
 #'   keep <- 0.1 * i
-#'   plot(simplify(FR, keep), main=paste0("keep = ", keep))
+#'   geom <-
+#'     FR %>%
+#'     simplify(keep) %>%
+#'     sf::st_geometry()
+#'   plot(geom, main=paste0("keep = ", keep))
 #' }
 #' layout(1)
 #' par(mar = c(5,4,4,2)+.1)
 #' }
 
 simplify <- function(
-  SPDF,
+  SFDF,
   keep = 0.05,
   ...
 ) {
-  SPDF_simple <- rmapshaper::ms_simplify(SPDF, keep, ...)
-  return(SPDF_simple)
+  SFDF_simple <- rmapshaper::ms_simplify(SFDF, keep, ...)
+  return(SFDF_simple)
 }
 
 
 #' @export
-#' @title Aggregate shapes in a SpatialPolygonsDataFrame
-#' @param SPDF Object of class SpatialPolygonsDataFrame.
+#' @title Aggregate shapes in a simple features data frame
+#' @param SFDF Object of class simple features data frame.
 #' @param field Name of the field to dissolve on.
 #' @param sum_fields Names of fields to sum.
 #' @param copy_fields Names of fields to copy. The first instance of each field will be
 #' copied to the aggregated feature
 #' @param ... arguments passed to \code{rmapshaper::ms_dissolve()}
 #' @description Aggregate shapes in a spatial polygons dataframe. This is a
-#' convenience wrapper for \code{rmapshaper::ms_dissolve()}
+#' convenience wrapper for \code{\link[rmapshaper]{ms_dissolve}}.
 #' @return A spatial polygons dataframe with aggregated shapes.
 #' @examples
 #' \donttest{
 #' regions <- dissolve(SimpleCountries, field = "UN_region", sum_fields = "area")
 #' plot(regions)
-#' regions@data
+#' dplyr::glimpse(regions)
 #' }
 
 dissolve <- function(
-  SPDF,
+  SFDF,
   field = NULL,
   sum_fields = NULL,
   copy_fields = NULL,
   ...
 ) {
 
-  if (!field %in% names(SPDF)) {
+  if (!field %in% names(SFDF))
     stop(paste0("Field '", field, "' not found."))
-  }
-  SPDF_dissolved <- rmapshaper::ms_dissolve(SPDF, field, sum_fields, copy_fields, ...)
 
-  return(SPDF_dissolved)
+  SFDF_dissolved <- rmapshaper::ms_dissolve(SFDF, field, sum_fields, copy_fields, ...)
+
+  return(SFDF_dissolved)
 
 }
 
