@@ -5,7 +5,7 @@
 #'
 #' @param longitude Vector of longitudes in decimal degrees East.
 #' @param latitude Vector of latitudes in decimal degrees North.
-#' @param dataset Name of spatial dataset to use.
+#' @param datasetName Name of spatial dataset to use.
 #' @param countryCodes Vector of ISO 3166-1 alpha-2 country codes.
 #' @param allData Logical specifying whether a full dataframe should be returned.
 #' @param useBuffering Logical flag specifying the use of location buffering to
@@ -24,20 +24,18 @@
 #' @examples
 #' library(MazamaSpatialUtils)
 #'
-#' longitude <- seq(-120,-60,5)
-#' latitude <- seq(20,80,5)
+#' longitude <- seq(-120, -60, 5)
+#' latitude <- seq(20, 80, 5)
 #'
 #' getTimezone(longitude, latitude)
 #'
-#' @references \url{http://efele.net/maps/tz/}
-#'
-#' @seealso SimpleTimezones
-#' @seealso getSpatialData
+#' @references \url{https://github.com/evansiroky/timezone-boundary-builder}
+
 #'
 getTimezone <- function(
   longitude = NULL,
   latitude = NULL,
-  dataset = "SimpleTimezones",
+  datasetName = "SimpleTimezones",
   countryCodes = NULL,
   allData = FALSE,
   useBuffering = FALSE
@@ -47,43 +45,35 @@ getTimezone <- function(
 
   MazamaCoreUtils::stopIfNull(longitude)
   MazamaCoreUtils::stopIfNull(latitude)
-  MazamaCoreUtils::stopIfNull(dataset)
+  MazamaCoreUtils::stopIfNull(datasetName)
   MazamaCoreUtils::stopIfNull(allData)
   MazamaCoreUtils::stopIfNull(useBuffering)
 
   # Check existence of dataset
-  if ( !exists(dataset) ) {
-    stop("Missing dataset. Please loadSpatialData(\"", dataset, "\")",
+  if ( !exists(datasetName) ) {
+    stop("Missing dataset. Please loadSpatialData(\"", datasetName, "\")",
          call. = FALSE)
   }
 
-  # Check longitude, latitude ranges
-  if ( min(longitude, na.rm = TRUE) < -180 ||
-       max(longitude, na.rm = TRUE) > 180) {
-    stop("'longitude' must be specified in the range -180:180.")
-  }
-  if ( min(latitude, na.rm = TRUE) < -90 ||
-       max(latitude, na.rm = TRUE) > 90 ) {
-    stop("'latitude' must be specified in the range -90:90.")
-  }
+  MazamaCoreUtils::validateLonsLats(longitude, latitude, na.rm = TRUE)
 
   # ----- Get the data ---------------------------------------------------------
 
-  SPDF <- get(dataset)
+  SFDF <- get(datasetName)
 
   # Subset by country before searching
   if (!is.null(countryCodes))
-    SPDF <- SPDF[SPDF$countryCode %in% countryCodes,]
+    SFDF <- SFDF[SFDF$countryCode %in% countryCodes,]
 
-  SPDF <- getSpatialData(longitude, latitude, SPDF, useBuffering = useBuffering)
+  SFDF <- getSpatialData(longitude, latitude, SFDF, useBuffering = useBuffering)
 
   if (allData) {
 
-    return(SPDF)
+    return(SFDF)
 
   } else {
 
-    timezone <- SPDF$timezone
+    timezone <- SFDF$timezone
 
     return(timezone)
 
